@@ -12,6 +12,7 @@ import math
 import gobject
 import pygst
 import email
+
 pygst.require('0.10')
 gobject.threads_init()
 import gst
@@ -42,7 +43,7 @@ class MailFolder:
 		self.name = foldername.split("__")[0]
 		self.domain = foldername.split("__")[1].replace("_", ":")
 		self.messages = []
-		self.type = foldertype
+		self.foldertype = foldertype
 	def check(self):
 		try:
 			messages = os.listdir('/home/user/.modest/cache/mail/'+self.foldertype+'/'+self.foldername+'/folders/INBOX/')
@@ -54,6 +55,8 @@ class MailFolder:
 			return unread
 		except OSError:
 			return []
+	def all(self):
+		return [email.message_from_file(open('/home/user/.modest/cache/mail/'+self.foldertype+'/'+self.foldername+'/folders/INBOX/'+i)) for i in self.messages[:10]]
 
 class Saera:
 	def __init__(self):
@@ -110,7 +113,7 @@ class Saera:
 		self.init_mail()
 		
 		# Commented out because there is a bug in the sqlite line that I can't find.
-		#gobject.timeout_add(10000, self.check_texts)
+		gobject.timeout_add(10000, self.check_texts)
 
 		self.current_message = None
 
@@ -266,22 +269,20 @@ class Saera:
 		# smsp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text, outgoing, is_read, \
 		# 				storage_time from Events where service_id=3 and event_type_id=11 and outgoing=0 and is_read=0 \
 		# 				order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=11 and outgoing=0"')
-		smsp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text from Events where \
-						service_id=3 and event_type_id=11 and outgoing=0 and is_read=0 \
-						order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=11 and outgoing=0 and is_read=0"')
+		smsp=os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-v1.db "Select remote_uid, free_text from Events where service_id=3 and event_type_id=11 and outgoing=0 and is_read=0 order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=11 and outgoing=0"')
 		sms_texts = smsp.read()
 		smsp.close()
 		# imp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text, outgoing, is_read, \
 		# 				storage_time from Events where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0 \
 		# 				order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=4 and outgoing=0"')
-		imp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text from Events where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0 \
-						order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0"')
-		im_texts = imp.read()
+		imp=os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-v1.db "Select remote_uid, free_text from Events where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0 order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=4 and outgoing=0"')
+		im_texts = imp.read().strip()
 		imp.close()
 		smsp = sms_texts.split('\n')
 		imp = im_texts.split('\n')
 		imp = smsp+imp
 		imp = [j for j in [[i.split("|")[0],"|".join(i.split("|")[1:])] for i in imp] if j]
+		imp = [j for j in imp if j[0] and j[1]]
 		self.ims = imp
 		gobject.timeout_add(10000, self.check_texts)
 		self.read_ims()
@@ -315,6 +316,23 @@ class Saera:
 					self.lines = self.lines[-20:]
 					self.darea.queue_draw()
 					gobject.timeout_add(100, os.system, saera_processing.sent.espeak_cmdline+' "'+words+'"')
+	def read_all_emails(self):
+		self.pipeline.set_state(gst.STATE_PAUSED)
+		result = []
+		for i in self.imap_mailfolders:
+			result = result+i.all()
+		for i in self.pop_mailfolders:
+			result = result+i.all()
+		for i in result:
+			if '"' in i['From']:
+				fro = i['From'].split('"')[1]
+			else:
+				fro = ''.join(''.join(i['From'].split('<')).split('>'))
+			words = "Email from "+fro+".\nSubject: "+i['Subject']+'.\nMessage: '+i.get_payload().replace('"', '\\"')
+			self.lines.append([words, False])
+			self.lines = self.lines[-20:]
+			self.darea.queue_draw()
+			gobject.timeout_add(100, os.system, saera_processing.sent.espeak_cmdline+' "'+words+'"')
 
 	def read_ims(self):
 		try:
@@ -426,6 +444,7 @@ class Saera:
 		ct2.paint()
 		self.darea.queue_draw()
 
+
 	def init_mail(self):
 		try:
 			imap_mailfolder = '/home/user/.modest/cache/mail/imap/'
